@@ -1,7 +1,9 @@
 package Sah::Schema::filesize;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-DataSizeSpeed'; # DIST
+our $VERSION = '0.005'; # VERSION
 
 our $schema = ['float' => {
     summary => 'File size',
@@ -19,6 +21,14 @@ Can be coerced from string that contains units, e.g.:
 _
     min => 0,
     'x.perl.coerce_rules' => ['From_str::suffix_filesize'],
+    examples => [
+        {data=>'2KB', valid=>1, res=>2*1024},
+        {data=>'2 kb', valid=>1, res=>2*1024},
+        {data=>'2mb', valid=>1, res=>2*1024*1024},
+        {data=>'1.5K', valid=>1, res=>1536},
+        {data=>'1.6ki', valid=>1, res=>1600},
+        {data=>'1zzz', valid=>0},
+    ],
 }, {}];
 
 1;
@@ -37,7 +47,23 @@ Sah::Schema::filesize - File size
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::filesize (from Perl distribution Sah-Schemas-DataSizeSpeed), released on 2019-11-29.
+This document describes version 0.005 of Sah::Schema::filesize (from Perl distribution Sah-Schemas-DataSizeSpeed), released on 2020-03-02.
+
+=head1 SYNOPSIS
+
+Sample data:
+
+ "2KB"  # valid, becomes 2048
+
+ "2 kb"  # valid, becomes 2048
+
+ "2mb"  # valid, becomes 2097152
+
+ "1.5K"  # valid, becomes 1536
+
+ "1.6ki"  # valid, becomes 1600
+
+ "1zzz"  # INVALID
 
 =head1 DESCRIPTION
 
@@ -72,7 +98,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
